network

package
v0.0.0-...-abca301 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 29, 2021 License: ISC Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SendImg

func SendImg(url string, img *image.RGBA) error

Send image to Discord bot

func SendStored

func SendStored() error

Send all the images that have been previously stored and delete them once they got sent. If it's not possible to send them they will be kept stored.

func StoreImg

func StoreImg(img image.Image, name string) error

Store image in case the remote host is (temporarily) offline. Make sure the file does not exist or it will be overwritten.

Types

This section is empty.

Jump to