Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SendStored ¶
func SendStored() error
Send all the images that have been previously stored and delete them once they got sent. If it's not possible to send them they will be kept stored.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.